[−][src]Enum double_ratchet::DecryptError
Error that may occur during ratchet_decrypt
Variants
DecryptFailureCould not verify-decrypt the ciphertext + associated data + header
MessageKeyNotFoundCould not find the message key required for decryption
Note that this implementation is not always able to detect when a MessageKey can't be
found: a DecryptFailure may be triggered instead.
SkipTooLargeHeader message counter is too large
StorageFullStorage of skipped message keys is full